@@ -2,7 +2,7 @@
 #define oxygenmenustatedata_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -30,6 +30,8 @@
 
 #include <gtk/gtk.h>
 
+#include <map>
+
 namespace Oxygen
 {
     //! handles menu items animations
@@ -124,6 +126,12 @@ namespace Oxygen
 
         protected:
 
+        //! register child
+        void registerChild( GtkWidget* );
+
+        //! disconnect child
+        void unregisterChild( GtkWidget* );
+
         //! update items
         void updateItems( void );
 
@@ -230,6 +238,9 @@ namespace Oxygen
         //!@name callbacks
         //@{
 
+        //! child is destroyed
+        static gboolean childDestroyNotifyEvent( GtkWidget*, gpointer );
+
         //! mouse motion events
         static gboolean motionNotifyEvent( GtkWidget*, GdkEventMotion*, gpointer);
 
@@ -284,6 +295,10 @@ namespace Oxygen
 
         //@}
 
+        //! map children to destroy signal
+        typedef std::map<GtkWidget*, Signal> ChildrenMap;
+        ChildrenMap _children;
+
     };
 
 }
